@@ -2,7 +2,7 @@
 Caching framework.
 """
 
-__version__ = "0.1.3"
+__version__ = "0.2.2"
 
 from functools import wraps
 from importlib import import_module
@@ -87,10 +87,10 @@ def cache(
         def wrapper(*args, **kwargs):
             return cache(*args, **kwargs)
 
-        def cache_clear():
+        def cache_clear(*args, **kwargs):
             """Clear the cache and cache statistics"""
-            cache.cache_clear()
-            CacheDependency.dependent_cache_clear(cache)
+            cache.cache_clear(args, kwargs)
+            CacheDependency.dependent_cache_clear(cache, args, kwargs)
 
         for item in dependency:
             item.cache_objects.add(cache)
@@ -113,6 +113,7 @@ def redis_cache(
     is_method: bool = False,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -121,6 +122,7 @@ def redis_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
 
 
@@ -131,6 +133,7 @@ def memory_cache(
     is_method: bool = False,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -139,6 +142,7 @@ def memory_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_MEMORY_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
 
 
@@ -148,6 +152,7 @@ def method_memory_cache(
     expire: Optional[int] = None,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -156,6 +161,7 @@ def method_memory_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_MEMORY_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
 
 
@@ -165,6 +171,7 @@ def method_redis_cache(
     expire: Optional[int] = None,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -173,6 +180,7 @@ def method_redis_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
 
 
@@ -182,6 +190,7 @@ def property_memory_cache(
     expire: Optional[int] = None,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -190,6 +199,7 @@ def property_memory_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_MEMORY_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
 
 
@@ -199,6 +209,7 @@ def property_redis_cache(
     expire: Optional[int] = None,
     strict: bool = False,
     dependency: Optional[List[CacheDependency]] = None,
+    **kwargs,
 ) -> CacheDecoratorType:
     return cache(
         limit=limit,
@@ -207,4 +218,5 @@ def property_redis_cache(
         strict=strict,
         backend=DefaultConfig.get_current_config().CACHE_ALCHEMY_REDIS_BACKEND,
         dependency=dependency or [],
+        **kwargs,
     )
